@@ -1,20 +1,21 @@
 # coding=utf-8
 import logging
 import os
+
 import Pyro4
 
 from pyage.core import address
 from pyage.core.agent.agent import unnamed_agents
 from pyage.core.agent.aggregate import AggregateAgent
 from pyage.core.emas import EmasService
-from pyage.core.locator import  RowLocator
+from pyage.core.locator import TorusLocator
 from pyage.core.migration import Pyro4Migration
-from pyage.core.statistics import  TimeStatistics
+from pyage.core.statistics import NoStatistics
 from pyage.core.stop_condition import StepLimitStopCondition
-from pyage.solutions.evolution.crossover import   SinglePointCrossover
-from pyage.solutions.evolution.evaluation import  FloatRastriginEvaluation
-from pyage.solutions.evolution.initializer import  float_emas_initializer
-from pyage.solutions.evolution.mutation import  UniformFloatMutation
+from pyage.solutions.evolution.crossover import SinglePointCrossover
+from pyage.solutions.evolution.evaluation import FloatRastriginEvaluation
+from pyage.solutions.evolution.initializer import float_emas_initializer
+from pyage.solutions.evolution.mutation import UniformFloatMutation
 
 
 logger = logging.getLogger(__name__)
@@ -41,11 +42,12 @@ mutation = lambda: UniformFloatMutation(probability=1, radius=1)
 
 address_provider = address.SequenceAddressProvider
 
-migration = Pyro4Migration
-locator = RowLocator
+torus = TorusLocator(10, 10)
+locator = lambda: torus
 
+migration = Pyro4Migration
 ns_hostname = lambda: os.environ['NS_HOSTNAME']
 pyro_daemon = Pyro4.Daemon()
 daemon = lambda: pyro_daemon
 
-stats = TimeStatistics
\ No newline at end of file
+stats = NoStatistics
\ No newline at end of file
