@@ -1,9 +1,14 @@
+import logging
 from pyage.core.address import Addressable
 from pyage.core.agent.agent import AbstractAgent
-from pyage.core.inject import Inject
+from pyage.core.inject import Inject, InjectOptional
+
+logger = logging.getLogger(__name__)
+
 
 class AggregateAgent(Addressable, AbstractAgent):
     @Inject("aggregated_agents:_AggregateAgent__agents")
+    @InjectOptional("locator")
     def __init__(self, name=None):
         self.name = name
         super(AggregateAgent, self).__init__()
@@ -17,6 +22,7 @@ class AggregateAgent(Addressable, AbstractAgent):
 
     def remove_agent(self, agent):
         del self.__agents[agent.get_address()]
+        self.locator.remove_agent(agent)
         agent.parent = None
         return agent
 
@@ -36,6 +42,16 @@ class AggregateAgent(Addressable, AbstractAgent):
     def get_best_genotype(self):
         return max(self.__agents.values(), key=lambda a: a.get_fitness()).get_best_genotype()
 
+    def move(self, agent):
+        allowed_moves = self.locator.get_allowed_moves(self)
+        if allowed_moves:
+            self.locator.remove_agent(self)
+            destination = get_random_move(allowed_moves)
+            self.locator.add_agent(self, destination)
+            logger.debug("%s moved to %s" % (self, destination))
+
+    def get_neighbour(self, agent):
+        self.locator.get_neighbour(agent)
 
 def aggregate_agents_factory(*args):
     def factory():
@@ -45,4 +61,9 @@ def aggregate_agents_factory(*args):
             agents[agent.get_address()] = agent
         return agents
 
-    return factory
\ No newline at end of file
+    return factory
+
+
+def get_random_move(allowed_moves):
+    destination = random.sample(allowed_moves, 1)[0]
+    return destination
\ No newline at end of file
